/* test_cyress.h
 * Mike Crist
 * 19 Jul 09
 *
 * Define constant packets, addresses, lengths, etc. for writing to the
 * CY3240 USB HID to I2C converter
 */

#ifndef __TEST_CYPRESS_H__
#define __TEST_CYPRESS_H__

  /* Packets for the CY3240 are always 64 bytes */
  #define SEND_PACKET_LEN 64
  #define RECV_PACKET_LEN 64
  #define PATHLEN         3

  /* Define all the control bits according to Cypress docs */
  #define I2C_WRITE       0 
  #define I2C_READ        1 
  #define I2C_START       2 
  #define I2C_RESTART     4 
  #define I2C_STOP        8 
  #define I2C_REINIT     10 
  #define I2C_RECONFIG   20 

  /* Define the "last packet" control bit for the length field */
  #define ISC_MORE_PACKETS 80
  #define I2C_LAST_PACKET  0
  
  /* Define speeds for reconfiguration */
  #define I2C_100KHZ     0
  #define I2C_400KHZ     4
  #define I2C_50KHZ      8

  /* Define the power bits */
  #define POWER_EXTERNAL 0
  #define POWER_5V       1
  #define POWER_3_3V     2

  /* Define the data byte locations for the example device */
  #define DATA_OFFSET    3
  #define UNK_0          0 + DATA_OFFSET
  #define UNK_1          1 + DATA_OFFSET
  #define UNK_2          2 + DATA_OFFSET
  #define UNK_3          3 + DATA_OFFSET
  #define UNK_4          4 + DATA_OFFSET
  #define LED_NUMBER     5 + DATA_OFFSET
  #define BRIGHTNESS     6 + DATA_OFFSET
  #define UNK_7          7 + DATA_OFFSET

  /* Define the device addresses used */
  #define CONTROL_0      0x80
  #define CONTROL_1      0x81
  #define PSOC           0x00  /* example device shipped in dev kit */

  /* Control paths, not really sure when these are used */
  const int PATH_IN[PATHLEN]  = { 0xffa00001, 0xffa00002, 0xffa00004 };
  const int PATH_OUT[PATHLEN] = { 0xffa00001, 0xffa00002, 0xffa00003 };
  
  /* Interrupt endpoints, the primary mechanism to send and receive
   * I2C data
   */
  const int INPUT_ENDPOINT   = 0x82;
  const int OUTPUT_ENDPOINT  = 0x01;
 
  int init_hid(HIDInterface*);
  int cleanup_hid(HIDInterface*);
  int print_packet(unsigned char *);
  int print_receive_control_packet(unsigned char *);
  int build_packet(unsigned char, unsigned char, unsigned char, unsigned char *);
#endif
